==> ejc-sddjsorg-impl-3.0.0-20211019.091636-32-sources.jar: com/ejianc/business/sddjsorg/bean/OrgShareholderEntity.java <==
package com.ejianc.business.sddjsorg.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 组织/申请单股东信息表(共用)
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_org_shareholder")
public class OrgShareholderEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表id(申请单id)
    @TableField(value="in_out_captail")
    private String inOutCaptail; // 内/外部出资方
    @TableField(value="captail_name")
    private String captailName; // 出资方名称
    @TableField(value="captail_id")
    private Long captailId; // 内部出资方名称
    @TableField(value="unified_social_credit_code")
    private String unifiedSocialCreditCode; // 统一社会信用编码
    @TableField(value="captail_type")
    private String captailType; // 出资人类别
    @TableField(value="contribution_type")
    private String contributionType; // 出资类别
    @TableField(value="subscribed_capital")
    private java.math.BigDecimal subscribedCapital; // 认缴资本
    @TableField(value="subscribed_capital_big")
    private String subscribedCapitalBig; // 认缴资本(大写)
    @TableField(value="paid_capital")
    private java.math.BigDecimal paidCapital; // 实缴资本
    @TableField(value="paid_capital_big")
    private String paidCapitalBig; // 实缴资本(大写)
    @TableField(value="equity_ratio")
    private java.math.BigDecimal equityRatio; // 股权比例
    

    /**
     * 主表id(申请单id)
     */
    public Long getPid() {
        return pid;
    }

    /**
     * 主表id(申请单id)
     */
    public void setPid(Long pid) {
        this.pid = pid;
    }
    /**
     * 内/外部出资方
     */
    public String getInOutCaptail() {
        return inOutCaptail;
    }

    /**
     * 内/外部出资方
     */
    public void setInOutCaptail(String inOutCaptail) {
        this.inOutCaptail = inOutCaptail;
    }
    /**
     * 出资方名称
     */
    public String getCaptailName() {
        return captailName;
    }

    /**
     * 出资方名称
     */
    public void setCaptailName(String captailName) {
        this.captailName = captailName;
    }
    /**
     * 统一社会信用编码
     */
    public String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用编码
     */
    public void setUnifiedSocialCreditCode(String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 出资人类别
     */
    public String getCaptailType() {
        return captailType;
    }

    /**
     * 出资人类别
     */
    public void setCaptailType(String captailType) {
        this.captailType = captailType;
    }
    /**
     * 认缴资本
     */
    public java.math.BigDecimal getSubscribedCapital() {
        return subscribedCapital;
    }

    /**
     * 认缴资本
     */
    public void setSubscribedCapital(java.math.BigDecimal subscribedCapital) {
        this.subscribedCapital = subscribedCapital;
    }
    /**
     * 认缴资本(大写)
     */
    public String getSubscribedCapitalBig() {
        return subscribedCapitalBig;
    }

    /**
     * 认缴资本(大写)
     */
    public void setSubscribedCapitalBig(String subscribedCapitalBig) {
        this.subscribedCapitalBig = subscribedCapitalBig;
    }
    /**
     * 实缴资本
     */
    public java.math.BigDecimal getPaidCapital() {
        return paidCapital;
    }

    /**
     * 实缴资本
     */
    public void setPaidCapital(java.math.BigDecimal paidCapital) {
        this.paidCapital = paidCapital;
    }
    /**
     * 实缴资本(大写)
     */
    public String getPaidCapitalBig() {
        return paidCapitalBig;
    }

    /**
     * 实缴资本(大写)
     */
    public void setPaidCapitalBig(String paidCapitalBig) {
        this.paidCapitalBig = paidCapitalBig;
    }
    /**
     * 股权比例
     */
    public java.math.BigDecimal getEquityRatio() {
        return equityRatio;
    }

    /**
     * 股权比例
     */
    public void setEquityRatio(java.math.BigDecimal equityRatio) {
        this.equityRatio = equityRatio;
    }

	public Long getCaptailId() {
		return captailId;
	}

	public void setCaptailId(Long captailId) {
		this.captailId = captailId;
	}

	public String getContributionType() {
		return contributionType;
	}

	public void setContributionType(String contributionType) {
		this.contributionType = contributionType;
	}
    
}

==> ejc-sddjsorg-impl-3.0.0-20211021.092501-45-sources.jar: com/ejianc/business/sddjsorg/bean/OrgShareholderEntity.java <==
package com.ejianc.business.sddjsorg.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 组织/申请单股东信息表(共用)
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_org_shareholder")
public class OrgShareholderEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表id(申请单id)
    @TableField(value="in_out_captail")
    private String inOutCaptail; // 内/外部出资方
    @TableField(value="captail_name")
    private String captailName; // 出资方名称
    @TableField(value="captail_id")
    private Long captailId; // 内部出资方名称
    @TableField(value="unified_social_credit_code")
    private String unifiedSocialCreditCode; // 统一社会信用编码
    @TableField(value="captail_type")
    private String captailType; // 出资人类别
    @TableField(value="contribution_type")
    private String contributionType; // 出资类别
    @TableField(value="subscribed_capital")
    private java.math.BigDecimal subscribedCapital; // 认缴资本
    @TableField(value="subscribed_capital_big")
    private String subscribedCapitalBig; // 认缴资本(大写)
    @TableField(value="paid_capital")
    private java.math.BigDecimal paidCapital; // 实缴资本
    @TableField(value="paid_capital_big")
    private String paidCapitalBig; // 实缴资本(大写)
    @TableField(value="equity_ratio")
    private java.math.BigDecimal equityRatio; // 股权比例
    @TableField(value="remarks")
    private String remarks; // 备注
    

    /**
     * 主表id(申请单id)
     */
    public Long getPid() {
        return pid;
    }

    /**
     * 主表id(申请单id)
     */
    public void setPid(Long pid) {
        this.pid = pid;
    }
    /**
     * 内/外部出资方
     */
    public String getInOutCaptail() {
        return inOutCaptail;
    }

    /**
     * 内/外部出资方
     */
    public void setInOutCaptail(String inOutCaptail) {
        this.inOutCaptail = inOutCaptail;
    }
    /**
     * 出资方名称
     */
    public String getCaptailName() {
        return captailName;
    }

    /**
     * 出资方名称
     */
    public void setCaptailName(String captailName) {
        this.captailName = captailName;
    }
    /**
     * 统一社会信用编码
     */
    public String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用编码
     */
    public void setUnifiedSocialCreditCode(String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 出资人类别
     */
    public String getCaptailType() {
        return captailType;
    }

    /**
     * 出资人类别
     */
    public void setCaptailType(String captailType) {
        this.captailType = captailType;
    }
    /**
     * 认缴资本
     */
    public java.math.BigDecimal getSubscribedCapital() {
        return subscribedCapital;
    }

    /**
     * 认缴资本
     */
    public void setSubscribedCapital(java.math.BigDecimal subscribedCapital) {
        this.subscribedCapital = subscribedCapital;
    }
    /**
     * 认缴资本(大写)
     */
    public String getSubscribedCapitalBig() {
        return subscribedCapitalBig;
    }

    /**
     * 认缴资本(大写)
     */
    public void setSubscribedCapitalBig(String subscribedCapitalBig) {
        this.subscribedCapitalBig = subscribedCapitalBig;
    }
    /**
     * 实缴资本
     */
    public java.math.BigDecimal getPaidCapital() {
        return paidCapital;
    }

    /**
     * 实缴资本
     */
    public void setPaidCapital(java.math.BigDecimal paidCapital) {
        this.paidCapital = paidCapital;
    }
    /**
     * 实缴资本(大写)
     */
    public String getPaidCapitalBig() {
        return paidCapitalBig;
    }

    /**
     * 实缴资本(大写)
     */
    public void setPaidCapitalBig(String paidCapitalBig) {
        this.paidCapitalBig = paidCapitalBig;
    }
    /**
     * 股权比例
     */
    public java.math.BigDecimal getEquityRatio() {
        return equityRatio;
    }

    /**
     * 股权比例
     */
    public void setEquityRatio(java.math.BigDecimal equityRatio) {
        this.equityRatio = equityRatio;
    }

	public Long getCaptailId() {
		return captailId;
	}

	public void setCaptailId(Long captailId) {
		this.captailId = captailId;
	}

	public String getContributionType() {
		return contributionType;
	}

	public void setContributionType(String contributionType) {
		this.contributionType = contributionType;
	}

	public String getRemarks() {
		return remarks;
	}

	public void setRemarks(String remarks) {
		this.remarks = remarks;
	}

}
